:: ==================================================================================
:: NAME:	Reset Windows Update Tool.
:: DESCRIPTION:	This script reset the Windows Update Components.
:: AUTHOR:	Manuel Gil.
:: VERSION:	10.5.3.2
:: Source:	https://gallery.technet.microsoft.com/scriptcenter/Reset-Windows-Update-Agent-d824badc
:: Translation	
:: German by: 	Alexander Jacubowsky, Jacubowsky EDV, July-Oct. 2017
:: last update:	 26.10.2017
:: ==================================================================================


:: Set console.
:: void mode();
:: /************************************************************************************/
:mode
	echo off
	title Reset Windows Update Tool DE.
	mode con cols=90 lines=32
	color 17
	cls

	goto getValues
goto :eof
:: /************************************************************************************/


:: Print Top Text.
::		@param - text = the text to print (%*).
:: void print(string text);
:: /*************************************************************************************/
:print
	cls
	echo.
	echo.%name% [Version: %version%]
	echo.Reset Windows Update Tool DE.
	echo.
	echo.%*
	echo.
goto :eof
:: /*************************************************************************************/


:: Add Value in the Registry.
::		@param - key = the key or entry to be added (%~1).
::				value = the value to be added under the selected key (%~2).
::				type = the type for the registry entry (%~3).
::				data = the data for the new registry entry (%~4).
:: void addReg(string key, string value, string type, string data);
:: /*************************************************************************************/
:addReg
	reg add "%~1" /v "%~2" /t "%~3" /d "%~4" /f
goto :eof
:: /*************************************************************************************/


:: Load the system values.
:: void getValues();
:: /************************************************************************************/
:getValues
	for /f "tokens=4-5 delims=[] " %%a in ('ver') do set version=%%a%%b
	for %%a in (%version%) do set version=%%a

	if %version% EQU 5.1.2600 (
		:: Name: "Microsoft Windows XP"
		set name=Microsoft Windows XP
		:: Family: Windows 5
		set family=5
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 5.2.3790 (
		:: Name: "Microsoft Windows XP Professional x64 Edition"
		set name=Microsoft Windows XP Professional x64 Edition
		:: Family: Windows 5
		set family=5
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.0.6000 (
		:: Name: "Microsoft Windows Vista"
		set name=Microsoft Windows Vista
		:: Family: Windows 6
		set family=6
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.0.6001 (
		:: Name: "Microsoft Windows Vista SP1"
		set name=Microsoft Windows Vista SP1
		:: Family: Windows 6
		set family=6
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.0.6002 (
		:: Name: "Microsoft Windows Vista SP2"
		set name=Microsoft Windows Vista SP2
		:: Family: Windows 6
		set family=6
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.1.7600 (
		:: Name: "Microsoft Windows 7"
		set name=Microsoft Windows 7
		:: Family: Windows 7
		set family=7
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.1.7601 (
		:: Name: "Microsoft Windows 7 SP1"
		set name=Microsoft Windows 7 SP1
		:: Family: Windows 7
		set family=7
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.2.9200 (
		:: Name: "Microsoft Windows 8"
		set name=Microsoft Windows 8
		:: Family: Windows 8
		set family=8
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.3.9200 (
		:: Name: "Microsoft Windows 8.1"
		set name=Microsoft Windows 8.1
		:: Family: Windows 8
		set family=8
		:: Compatibility: Yes
		set allow=Yes
	) else if %version% EQU 6.3.9600 (
		:: Name: "Microsoft Windows 8.1 Update 1"
		set name=Microsoft Windows 8.1 Update 1
		:: Family: Windows 8
		set family=8
		:: Compatibility: Yes
		set allow=Yes
	) else (
		ver | find "10.0." > nul
		if %errorlevel% EQU 0 (
			:: Name: "Microsoft Windows 10"
			set name=Microsoft Windows 10
			:: Family: Windows 10
			set family=10
			:: Compatibility: Yes
			set allow=Yes
		) else (
			:: Name: "Unknown"
			set name=Unknown
			:: Compatibility: No
			set allow=No
		)
	)

	call :print %name% erkannt . . .

	if %allow% EQU Yes goto permission

	call :print Sorry, dieses Betriebssystem ist nicht kompatibel mit diesem Tool.

	echo.    Es ist ein Fehler beim ueberpruefen des Systems aufgetreten.
	echo.    Dies kann an einer Business oder Test/Insider version liegen.
	echo.
	echo.    Wenn nicht, ueberpruefen Sie ob der richtige security fix vorhanden ist.
	echo.

	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /************************************************************************************/


:: Checking for Administrator elevation.
:: void permission();
:: /************************************************************************************/
:permission
	openfiles>nul 2>&1

	if %errorlevel% EQU 0 goto terms

	call :print Pruefen auf Administrator rechte.

	echo.    Das Skript wurde nicht mit Administratorrechten gestartet.
	echo.    Dieses Tool kann ohne Adminrechte nicht funktionieren.
	echo.
	echo.    Bitte mit Administratorrechten starten: Rechts klick, dann 'Als Administrator ausfuehren'.
	echo.

	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /************************************************************************************/


:: Terms.
:: void terms();
:: /*************************************************************************************/
:terms
	call :print Nutzungsbedingungen.

	echo.    Die Methoden in diesem Tool aendern Dateien und Registrierungseinstellungen.
	echo.    Obwohl Sie getestet sind und funktionieren, uebernehmen wir nicht die Verantwortung 
	echo.    fuer die Verwendung dieses Tools.

	echo.    Dieses Tool wird ohne Gewaehrleistung bereitgestellt. Alle verursachten Schaeden 
	echo.    liegen in Ihrer eigene Verantwortung.
	echo.    Dieses Skript wird fast immer von Anti-Virus Programmen als gefaehlich gemeldet. 
	echo.    Bitte ueberpruefen Sie den Code, wenn Sie unsicher sind.
	echo.
	choice /c JN /n /m "Moechten Sie mit dem Prozess fortfahren? (Ja/Nein) "
	if %errorlevel% EQU 1 goto menu
	if %errorlevel% EQU 2 goto close

	echo. Ein unerwarteter Fehler ist aufgetreten.
	echo.
	echo. Zum Fortsetzen eine Taste druecken . . .
	pause>nul
	
	goto menu
goto :eof
:: /*************************************************************************************/


:: Menu of tool.
:: void menu();
:: /*************************************************************************************/
:menu
	call :print Dieses Tool setzt die Windows Update Komponenten zurueck.

	echo.    1. Oeffnen der Computerschutz Einstellungen.
	echo.    2. Windows Update Komponenten zuruecksetzen.
	echo.    3. Temporaere Windows-Dateien loeschen.
	echo.    4. Oeffnen der Internet Explorer optionen.
	echo.    5. Ueberpruefen aller geschuetzen Systemdateien.
	echo.    6. Scannen des Windows Image auf Beschaedigungen.
	echo.    7. Pruefen der gefundenen Beschaedigungen.
	echo.    8. Windows Image reparieren.
	echo.    9. Entfernen ersetzter Komponenten.
	echo.    10. Aendern von ungueltigen Eintraegen in the Registrierungsdatenbank.
	echo.    11. Winsock Einstellungen zuruecksetzen.
	echo.    12. Nach Updates suchen.
	echo.    13. Finden anderer lokaler Loesungen.
	echo.    14. Finden anderer online Loesungen.
	echo.    15. Diagnostic herunterladen.
	echo.    16. PC neustarten.
	echo.
	echo.                                            ?. Hilfe.    0. Beenden.
	echo.

	set /p option=Select an option: 

	if %option% EQU 0 (
		goto close
	) else if %option% EQU 1 (
		call :sysProtection
	) else if %option% EQU 2 (
		call :components
	) else if %option% EQU 3 (
		call :temp
	) else if %option% EQU 4 (
		call :iOptions
	) else if %option% EQU 5 (
		call :sfc
	) else if %option% EQU 6 (
		call :dism1
	) else if %option% EQU 7 (
		call :dism2
	) else if %option% EQU 8 (
		call :dism3
	) else if %option% EQU 9 (
		call :dism4
	) else if %option% EQU 10 (
		call :regedit
	) else if %option% EQU 11 (
		call :winsock
	) else if %option% EQU 12 (
		call :updates
	) else if %option% EQU 13 (
		call :local
	) else if %option% EQU 14 (
		call :online
	) else if %option% EQU 15 (
		call :diagnostic
	) else if %option% EQU 16 (
		call :restart
	) else if %option% EQU ? (
		call :help
	) else (
		echo.
		echo.Ungueltige Option.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
	)
	
	goto menu
goto :eof	
:: /*************************************************************************************/


:: Open system protection.
:: void sysProtection();
:: /*************************************************************************************/
:sysProtection
	call :print Oeffnen der Computerschutz Einstellungen.

	if %family% NEQ 5 (
		start systempropertiesprotection
	) else (
		echo.
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
	)
goto :eof
:: /*************************************************************************************/


:: Run the reset Windows Update components.
:: void components();
:: /*************************************************************************************/
:components
	:: ----- Stopping the Windows Update services -----
	call :print Stoppen der Windows Update Dienste [BITS].
	net stop bits

	call :print Stoppen the Windows Update Dienste [UPDATE].
	net stop wuauserv

	call :print Stoppen the Windows Update Dienste [APPID].
	net stop appidsvc

	call :print Stoppen the Windows Update Dienste [CRYPTO].
	net stop cryptsvc

	:: ----- Checking the services status -----
	call :print Pruefen des status der Dienste.

	sc query bits | findstr /I /C:"STOPPED"
	If %errorlevel% NEQ 0 (
		echo.    Fehler beim beenden des BITS Dienstes.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
		goto close
	)

	call :print Checking the services status.

	sc query wuauserv | findstr /I /C:"STOPPED"
	if %errorlevel% NEQ 0 (
		echo.    Fehler beim beenden des Windows Update Dienstes.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
		goto close
	)

	call :print Checking the services status.

	sc query appidsvc | findstr /I /C:"STOPPED"
	if %errorlevel% NEQ 0 (
		sc query appidsvc | findstr /I /C:"OpenService FAILED 1060"
		if %errorlevel% NEQ 0 (
			echo.    Fehler beim beenden des Application Identity Dienstes.
			echo.
			echo.Zum Fortsetzen eine Taste druecken . . .
			pause>nul
			if %family% NEQ 6 goto close
		)
	)

	call :print Checking the services status.

	sc query cryptsvc | findstr /I /C:"STOPPED"
	If %errorlevel% NEQ 0 (
		echo.    Fehler beim beenden des Cryptographic Services Dienstes.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
		goto close
	)

	:: ----- Delete the qmgr*.dat files -----
	call :print Loeschen der qmgr*.dat Dateien.

	del /s /q /f "%ALLUSERSPROFILE%\Application Data\Microsoft\Network\Downloader\qmgr*.dat"
	del /s /q /f "%ALLUSERSPROFILE%\Microsoft\Network\Downloader\qmgr*.dat"

	:: ----- Renaming the softare distribution folders backup copies -----
	call :print Loeschen von alten Softwareverteilungs Sicherungskopien.

	cd /d %SYSTEMROOT%

	if exist "%SYSTEMROOT%\winsxs\pending.xml.bak" (
		del /s /q /f "%SYSTEMROOT%\winsxs\pending.xml.bak"
	)
	if exist "%SYSTEMROOT%\SoftwareDistribution.bak" (
		rmdir /s /q "%SYSTEMROOT%\SoftwareDistribution.bak"
	)
	if exist "%SYSTEMROOT%\system32\Catroot2.bak" (
		rmdir /s /q "%SYSTEMROOT%\system32\Catroot2.bak"
	)
	if exist "%SYSTEMROOT%\WindowsUpdate.log.bak" (
		del /s /q /f "%SYSTEMROOT%\WindowsUpdate.log.bak"
	)

	call :print Umbenennen des Software distribution Ordners.

	if exist "%SYSTEMROOT%\winsxs\pending.xml" (
		takeown /f "%SYSTEMROOT%\winsxs\pending.xml"
		attrib -r -s -h /s /d "%SYSTEMROOT%\winsxs\pending.xml"
		ren "%SYSTEMROOT%\winsxs\pending.xml" pending.xml.bak
	)
	if exist "%SYSTEMROOT%\SoftwareDistribution" (
		attrib -r -s -h /s /d "%SYSTEMROOT%\SoftwareDistribution"
		ren "%SYSTEMROOT%\SoftwareDistribution" SoftwareDistribution.bak
	)
	if exist "%SYSTEMROOT%\system32\Catroot2" (
		attrib -r -s -h /s /d "%SYSTEMROOT%\system32\Catroot2"
		ren "%SYSTEMROOT%\system32\Catroot2" Catroot2.bak
	)
	if exist "%SYSTEMROOT%\WindowsUpdate.log" (
		attrib -r -s -h /s /d "%SYSTEMROOT%\WindowsUpdate.log"
		ren "%SYSTEMROOT%\WindowsUpdate.log" WindowsUpdate.log.bak
	)

	:: ----- Reset the BITS service and the Windows Update service to the default security descriptor -----
	call :print Zuruecksetzen von BITS- und Windows Update Dienst auf Standard Sicherheitseinstellungen.

	sc.exe sdset bits D:(A;;CCLCSWRPWPDTLOCRRC;;;SY)(A;;CCDCLCSWRPWPDTLOCRSDRCWDWO;;;BA)(A;;CCLCSWLOCRRC;;;AU)(A;;CCLCSWRPWPDTLOCRRC;;;PU)
	sc.exe sdset wuauserv D:(A;;CCLCSWRPWPDTLOCRRC;;;SY)(A;;CCDCLCSWRPWPDTLOCRSDRCWDWO;;;BA)(A;;CCLCSWLOCRRC;;;AU)(A;;CCLCSWRPWPDTLOCRRC;;;PU)

	:: ----- Reregister the BITS files and the Windows Update files -----
	call :print Neuregistrierung der BITS- und Windows Update Dateien.

	cd /d %WINDIR%\system32
	regsvr32.exe /s atl.dll
	regsvr32.exe /s urlmon.dll
	regsvr32.exe /s mshtml.dll
	regsvr32.exe /s shdocvw.dll
	regsvr32.exe /s browseui.dll
	regsvr32.exe /s jscript.dll
	regsvr32.exe /s vbscript.dll
	regsvr32.exe /s scrrun.dll
	regsvr32.exe /s msxml.dll
	regsvr32.exe /s msxml3.dll
	regsvr32.exe /s msxml6.dll
	regsvr32.exe /s actxprxy.dll
	regsvr32.exe /s softpub.dll
	regsvr32.exe /s wintrust.dll
	regsvr32.exe /s dssenh.dll
	regsvr32.exe /s rsaenh.dll
	regsvr32.exe /s gpkcsp.dll
	regsvr32.exe /s sccbase.dll
	regsvr32.exe /s slbcsp.dll
	regsvr32.exe /s cryptdlg.dll
	regsvr32.exe /s oleaut32.dll
	regsvr32.exe /s ole32.dll
	regsvr32.exe /s shell32.dll
	regsvr32.exe /s initpki.dll
	regsvr32.exe /s wuapi.dll
	regsvr32.exe /s wuaueng.dll
	regsvr32.exe /s wuaueng1.dll
	regsvr32.exe /s wucltui.dll
	regsvr32.exe /s wups.dll
	regsvr32.exe /s wups2.dll
	regsvr32.exe /s wuweb.dll
	regsvr32.exe /s qmgr.dll
	regsvr32.exe /s qmgrprxy.dll
	regsvr32.exe /s wucltux.dll
	regsvr32.exe /s muweb.dll
	regsvr32.exe /s wuwebv.dll

	:: ----- Resetting Winsock -----
	call :print Zuruecksetzen von Winsock.
	netsh winsock reset

	:: ----- Resetting WinHTTP Proxy -----
	call :print Zuruecksetzen von WinHTTP Proxy.

	if %family% EQU 5 (
		proxycfg.exe -d
	) else (
		netsh winhttp reset proxy
	)

	:: ----- Set the startup type as automatic -----
	call :print Zuruecksetzen der Dienste auf Automatisch.
	sc config wuauserv start= auto
	sc config bits start= auto
	sc config DcomLaunch start= auto

	:: ----- Starting the Windows Update services -----
	call :print Starten der Windows Update Dienste [BITS].
	net start bits

	call :print Starten der Windows Update services [WSUS].
	net start wuauserv

	call :print Starten der Windows Update services [APPID].
	net start appidsvc

	call :print Starten der Windows Update services [CRYPTO].
	net start cryptsvc

	call :print Starten der Windows Update services [DCOM].
	net start DcomLaunch

	:: ----- End process -----
	call :print Starten der Dienst abgeschlossen.

	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Delete temporary files in Windows.
:: void temp();
:: /*************************************************************************************/
:temp
	call :print Loeschen der Temporaeren Windows-Dateien.

	del /s /f /q "%TEMP%\*.*"
	del /s /f /q "%SYSTEMROOT%\Temp\*.*"

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Open the Internet Explorer options.
:: void iOptions();
:: /*************************************************************************************/
:iOptions
	call :print Oeffnen der Internet Explorer Optionen.

	start InetCpl.cpl
goto :eof
:: /*************************************************************************************/


:: Scans all protected system files.
:: void sfc();
:: /*************************************************************************************/
:sfc
	call :print Ueberpruefen aller geschuetzen Systemdateien.

	if %family% NEQ 5 (
		sfc /scannow
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	If %errorlevel% EQU 0 (
		echo.
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
	) else (
		echo.
		echo.Ein Fehler ist aufgetreten.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Scan the image to check for corruption.
:: void dism1();
:: /*************************************************************************************/
:dism1
	call :print Scannen des Windows Image auf Beschaedigungen.

	if %family% EQU 8 (
		Dism.exe /Online /Cleanup-Image /ScanHealth
	) else if %family% EQU 10 (
		Dism.exe /Online /Cleanup-Image /ScanHealth
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	If %errorlevel% EQU 0 (
		echo.
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
	) else (
		echo.
		echo.Ein Fehler ist aufgetreten.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Check the detected corruptions.
:: void dism2();
:: /*************************************************************************************/
:dism2
	call :print Pruefen der gefundenen Beschaedigungen.

	if %family% EQU 8 (
		Dism.exe /Online /Cleanup-Image /CheckHealth
	) else if %family% EQU 10 (
		Dism.exe /Online /Cleanup-Image /CheckHealth
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	If %errorlevel% EQU 0 (
		echo.
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
	) else (
		echo.
		echo.Ein Fehler ist aufgetreten.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Repair the image.
:: void dism3();
:: /*************************************************************************************/
:dism3
	call :print Windows Image reparieren.

	if %family% EQU 8 (
		Dism.exe /Online /Cleanup-Image /RestoreHealth
	) else if %family% EQU 10 (
		Dism.exe /Online /Cleanup-Image /RestoreHealth
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	If %errorlevel% EQU 0 (
		echo.
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
	) else (
		echo.
		echo.Ein Fehler ist aufgetreten.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Clean up the superseded components .
:: void dism4();
:: /*************************************************************************************/
:dism4
	call :print Entfernen ersetzter Komponenten.

	if %family% EQU 8 (
		Dism.exe /Online /Cleanup-Image /StartComponentCleanup
	) else if %family% EQU 10 (
		Dism.exe /Online /Cleanup-Image /StartComponentCleanup
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	If %errorlevel% EQU 0 (
		echo.
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
	) else (
		echo.
		echo.Ein Fehler ist aufgetreten.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Change invalid values.
:: void regedit();
:: /*************************************************************************************/
:regedit
	for /f "tokens=1-5 delims=/, " %%a in ("%date%") do (
		set now=%%a%%b%%c%%d%time:~0,2%%time:~3,2%
	)

	:: ----- Create a backup of the Registry -----
	call :print Sicherungskopie der Registrierung erstellen in: %USERPROFILE%\Desktop\Backup%now%.reg

	if exist "%USERPROFILE%\Desktop\Backup%now%.reg" (
		echo.Ein unerwarteter Fehler ist aufgetreten.
		echo.
		echo.    nderungen wurden nicht in der Registrierung durchgefhrt.
		echo.    Wird nochmal versucht.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
		goto :eof
	) else (
		regedit /e "%USERPROFILE%\Desktop\Backup%now%.reg"
	)

	:: ----- Checking backup -----
	call :print Pruefen der Sicherungskopie.

	if not exist "%USERPROFILE%\Desktop\Backup%now%.reg" (
		echo.Ein unerwarteter Fehler ist aufgetreten.
		echo.
		Echo.    Irgendwas lief schief.
		Echo.    Erstellen Sie manuell eine Sicherungskopie der Registrierung, bevor Sie fortfahren.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
	) else (
		echo.Der Vorgang wurde erfolgreich abgeschlossen.
		echo.
	)

	:: ----- Delete keys in the Registry -----
	call :print Loeschen der Eintraege in der Registrierung.

	reg delete "HKLM\SOFTWARE\Policies\Microsoft\Windows\WindowsUpdate" /f
	reg delete "HKLM\COMPONENTS\PendingXmlIdentifier" /f
	reg delete "HKLM\COMPONENTS\NextQueueEntryIndex" /f
	reg delete "HKLM\COMPONENTS\AdvancedInstallersNeedResolving" /f
	reg delete "HKLM\SOFTWARE\Microsoft\Windows\CurrentVersion\WindowsUpdate\Auto Update\RebootRequired" /f
	
	:: ----- Add keys in the Registry -----
	call :print Hinzufuegen der Eintraege in der Registrierung.

	set key=HKLM\SOFTWARE\Microsoft\WindowsUpdate\UX
	call :addReg "%key%" "IsConvergedUpdateStackEnabled" "REG_DWORD" "0"

	set key=HKLM\SOFTWARE\Microsoft\WindowsUpdate\UX\Settings
	call :addReg "%key%" "UxOption" "REG_DWORD" "0"

	set key=HKCU\Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders
	call :addReg "%key%" "AppData" "REG_EXPAND_SZ" "%USERPROFILE%\AppData\Roaming"

	set key=HKLM\Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders
	call :addReg "%key%" "AppData" "REG_EXPAND_SZ" "%USERPROFILE%\AppData\Roaming"

	set key=HKU\.DEFAULT\Software\Microsoft\Windows\CurrentVersion\Explorer\User Shell Folders
	call :addReg "%key%" "AppData" "REG_EXPAND_SZ" "%USERPROFILE%\AppData\Roaming"

	reg add "HKLM\SYSTEM\CurrentControlSet\Control\BackupRestore\FilesNotToBackup" /f

	reg query "HKLM\SOFTWARE\Policies\Microsoft\Windows\CurrentVersion\Internet Settings" /v Security_HKLM_only | find /i "Security_HKLM_Only" | find "1"

	if %errorlevel% EQU 0 (
		set key=HKLM\Software\Microsoft\Windows\CurrentVersion\Internet Settings\ZoneMap\Domains
	) else (
		set key=HKCU\Software\Microsoft\Windows\CurrentVersion\Internet Settings\ZoneMap\Domains
	)

	call :addReg "%key%\microsoft.com\update" "http" "REG_DWORD" "2"
	call :addReg "%key%\microsoft.com\update" "https" "REG_DWORD" "2"
	call :addReg "%key%\microsoft.com\windowsupdate" "http" "REG_DWORD" "2"
	call :addReg "%key%\update.microsoft.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\update.microsoft.com" "https" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.microsoft.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\download.microsoft.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.com" "https" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.com\download" "http" "REG_DWORD" "2"
	call :addReg "%key%\windowsupdate.com\download" "https" "REG_DWORD" "2"
	call :addReg "%key%\download.windowsupdate.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\download.windowsupdate.com" "https" "REG_DWORD" "2"
	call :addReg "%key%\windows.com\wustat" "http" "REG_DWORD" "2"
	call :addReg "%key%\wustat.windows.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\microsoft.com\ntservicepack" "http" "REG_DWORD" "2"
	call :addReg "%key%\ntservicepack.microsoft.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\microsoft.com\ws" "http" "REG_DWORD" "2"
	call :addReg "%key%\microsoft.com\ws" "https" "REG_DWORD" "2"
	call :addReg "%key%\ws.microsoft.com" "http" "REG_DWORD" "2"
	call :addReg "%key%\ws.microsoft.com" "https" "REG_DWORD" "2"

	:: ----- End process -----
	call :print Der Vorgang wurde erfolgreich abgeschlossen.

	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Reset Winsock setting.
:: void winsock();
:: /*************************************************************************************/
:winsock
	:: ----- Reset Winsock control -----
	call :print Zuruecksetzen von Winsock.

	call :print Wiederherstellen der Transaction logs.
	fsutil resource setautoreset true C:\

	call :print Wiederherstellen TPC/IP.
	netsh int ip reset

	call :print Wiederherstellen Winsock.
	netsh winsock reset

	call :print Wiederherstellen der Standardrichlinien Einstellungen.
	netsh advfirewall reset

	call :print Wiederherstellen des DNS Cache.
	ipconfig /flushdns

	call :print Wiederherstellen der Proxy einstellungen.
	netsh winhttp reset proxy

	:: ----- End process -----
	call :print Der Vorgang wurde erfolgreich abgeschlossen.

	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Search Updates.
:: void updates();
:: /*************************************************************************************/
:updates
	call :print Suche nach updates.

	echo. Kann lange dauern, bitte warten . . .
	echo.

	wuauclt /resetauthorization /detectnow

	if %family% EQU 10 (
		start ms-settings:windowsupdate
	) else (
		if %family% NEQ 5 (
			start wuapp.exe
		) else (
			echo.
			echo.Ein unerwarteter Fehler ist aufgetreten.
			echo.
			echo.Zum Fortsetzen eine Taste druecken . . .
			pause>nul
		)
	)
goto :eof
:: /*************************************************************************************/


:: Explore other local solutions.
:: void local();
:: /*************************************************************************************/
:local
	call :print Suche nach Loesungen auf diesem PC.

	if %family% NEQ 5 (
		start control.exe /name Microsoft.Troubleshooting
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
	)
goto :eof
:: /*************************************************************************************/


:: Explore other online solutions.
:: void online();
:: /*************************************************************************************/
:online
	call :print Suche nach Loesungen Online.

	start https://support.microsoft.com/de-de/help/12373/windows-update-faq
:: 	start https://support.microsoft.com/de-de/help/10164
:: 	start https://support.microsoft.com/en-gp/gp/windows-update-issues/
goto :eof
:: /*************************************************************************************/


:: Reboot the system.
:: void restart();
:: /*************************************************************************************/
:restart
	call :print Neustart des Computers.

	if %family% NEQ 5 (
		echo.    Das System wird in 60 Sekunden.
		echo.    Bitte alle Dokumente speichern.

		start shutdown.exe /r /t 60 /c "Das system startet in 60 Sek. neu. Bitte alle offenen Dokumente speichern."
	) else (
		echo.Sorry, diese Option ist in diesem Betriebssystem nicht vorhanden.
	)

	echo.
	echo.Zum Fortsetzen eine Taste druecken . . .
	pause>nul
goto :eof
:: /*************************************************************************************/


:: Open help file.
:: void help();
:: /*************************************************************************************/
:help
	start %~dp0Help.chm
goto :eof
:: /*************************************************************************************/


:: open Diagnostic menu
:: void diagnostic();
:: /*************************************************************************************/
:diagnostic
	call :print Herunterladen und starten eines Diagnoseprogramms fuer Ihr System.

	echo.    1. Windows Update auf Windows 7, Windows 8 und Windows 8.1.
	echo.    2. Windows Update auf Windows 10.
	echo.    3. Apps auf Windows 8.1.
	echo.    4. Apps auf Windows 10.
	echo.    5. Start Menu auf Windows 10.
	echo.
	echo.                                                        0. zurueck.
	echo.

	set /p option=Select an option: 

	if %option% EQU 0 (
		goto menu
	) else if %option% EQU 1 (
		start http://go.microsoft.com/?linkid=9830262
	) else if %option% EQU 2 (
		start http://aka.ms/diag_wu
	) else if %option% EQU 3 (
		start http://go.microsoft.com/fwlink/p/?LinkId=268423
	) else if %option% EQU 4 (
		start http://aka.ms/diag_apps10
	) else if %option% EQU 5 (
		start http://aka.ms/startmenuTS
	) else (
		echo.
		echo.Ungueltige Auswahl.
		echo.
		echo.Zum Fortsetzen eine Taste druecken . . .
		pause>nul
	)
 
	goto diagnostic
goto :eof
:: /*************************************************************************************/


:: End tool.
:: void close();
:: /*************************************************************************************/
:close
	exit
goto :eof
:: /*************************************************************************************/

